module.exports = {
	target: "web"
};
